@@ -25,50 +25,44 @@ class CreateConnectionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateConnection')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Description(self):
+	def get_Description(self): # String
 		return self.get_query_params().get('Description')
 
-	def set_Description(self,Description):
-		self.add_query_param('Description',Description)
-
-	def get_Content(self):
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_Content(self): # String
 		return self.get_query_params().get('Content')
 
-	def set_Content(self,Content):
-		self.add_query_param('Content',Content)
-
-	def get_SubType(self):
+	def set_Content(self, Content):  # String
+		self.add_query_param('Content', Content)
+	def get_SubType(self): # String
 		return self.get_query_params().get('SubType')
 
-	def set_SubType(self,SubType):
-		self.add_query_param('SubType',SubType)
-
-	def get_Name(self):
+	def set_SubType(self, SubType):  # String
+		self.add_query_param('SubType', SubType)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
-
-	def get_EnvType(self):
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
+	def get_EnvType(self): # Integer
 		return self.get_query_params().get('EnvType')
 
-	def set_EnvType(self,EnvType):
-		self.add_query_param('EnvType',EnvType)
-
-	def get_ConnectionType(self):
+	def set_EnvType(self, EnvType):  # Integer
+		self.add_query_param('EnvType', EnvType)
+	def get_ConnectionType(self): # String
 		return self.get_query_params().get('ConnectionType')
 
-	def set_ConnectionType(self,ConnectionType):
-		self.add_query_param('ConnectionType',ConnectionType)
-
-	def get_ProjectId(self):
+	def set_ConnectionType(self, ConnectionType):  # String
+		self.add_query_param('ConnectionType', ConnectionType)
+	def get_ProjectId(self): # Long
 		return self.get_query_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_query_param('ProjectId',ProjectId)
\ No newline at end of file
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_query_param('ProjectId', ProjectId)
