@@ -25,38 +25,34 @@ class CreateDataServiceFolderRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateDataServiceFolder')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_GroupId(self):
+	def get_GroupId(self): # String
 		return self.get_body_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
+	def set_GroupId(self, GroupId):  # String
 		self.add_body_params('GroupId', GroupId)
-
-	def get_TenantId(self):
-		return self.get_body_params().get('TenantId')
-
-	def set_TenantId(self,TenantId):
-		self.add_body_params('TenantId', TenantId)
-
-	def get_FolderName(self):
+	def get_FolderName(self): # String
 		return self.get_body_params().get('FolderName')
 
-	def set_FolderName(self,FolderName):
+	def set_FolderName(self, FolderName):  # String
 		self.add_body_params('FolderName', FolderName)
-
-	def get_ProjectId(self):
-		return self.get_body_params().get('ProjectId')
-
-	def set_ProjectId(self,ProjectId):
-		self.add_body_params('ProjectId', ProjectId)
-
-	def get_ParentId(self):
+	def get_ParentId(self): # Long
 		return self.get_body_params().get('ParentId')
 
-	def set_ParentId(self,ParentId):
-		self.add_body_params('ParentId', ParentId)
\ No newline at end of file
+	def set_ParentId(self, ParentId):  # Long
+		self.add_body_params('ParentId', ParentId)
+	def get_TenantId(self): # Long
+		return self.get_body_params().get('TenantId')
+
+	def set_TenantId(self, TenantId):  # Long
+		self.add_body_params('TenantId', TenantId)
+	def get_ProjectId(self): # Long
+		return self.get_body_params().get('ProjectId')
+
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_body_params('ProjectId', ProjectId)
