@@ -25,38 +25,34 @@ class CreateDataServiceGroupRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateDataServiceGroup')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ApiGatewayGroupId(self):
-		return self.get_body_params().get('ApiGatewayGroupId')
-
-	def set_ApiGatewayGroupId(self,ApiGatewayGroupId):
-		self.add_body_params('ApiGatewayGroupId', ApiGatewayGroupId)
-
-	def get_TenantId(self):
-		return self.get_body_params().get('TenantId')
-
-	def set_TenantId(self,TenantId):
-		self.add_body_params('TenantId', TenantId)
-
-	def get_Description(self):
+	def get_Description(self): # String
 		return self.get_body_params().get('Description')
 
-	def set_Description(self,Description):
+	def set_Description(self, Description):  # String
 		self.add_body_params('Description', Description)
-
-	def get_ProjectId(self):
-		return self.get_body_params().get('ProjectId')
-
-	def set_ProjectId(self,ProjectId):
-		self.add_body_params('ProjectId', ProjectId)
-
-	def get_GroupName(self):
+	def get_GroupName(self): # String
 		return self.get_body_params().get('GroupName')
 
-	def set_GroupName(self,GroupName):
-		self.add_body_params('GroupName', GroupName)
\ No newline at end of file
+	def set_GroupName(self, GroupName):  # String
+		self.add_body_params('GroupName', GroupName)
+	def get_ApiGatewayGroupId(self): # String
+		return self.get_body_params().get('ApiGatewayGroupId')
+
+	def set_ApiGatewayGroupId(self, ApiGatewayGroupId):  # String
+		self.add_body_params('ApiGatewayGroupId', ApiGatewayGroupId)
+	def get_TenantId(self): # Long
+		return self.get_body_params().get('TenantId')
+
+	def set_TenantId(self, TenantId):  # Long
+		self.add_body_params('TenantId', TenantId)
+	def get_ProjectId(self): # Long
+		return self.get_body_params().get('ProjectId')
+
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_body_params('ProjectId', ProjectId)
