@@ -25,80 +25,74 @@ class CreateUdfFileRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateUdfFile')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_CreateFolderIfNotExists(self): # Boolean
+		return self.get_body_params().get('CreateFolderIfNotExists')
 
-	def get_ReturnValue(self):
+	def set_CreateFolderIfNotExists(self, CreateFolderIfNotExists):  # Boolean
+		self.add_body_params('CreateFolderIfNotExists', CreateFolderIfNotExists)
+	def get_ReturnValue(self): # String
 		return self.get_body_params().get('ReturnValue')
 
-	def set_ReturnValue(self,ReturnValue):
+	def set_ReturnValue(self, ReturnValue):  # String
 		self.add_body_params('ReturnValue', ReturnValue)
-
-	def get_Resources(self):
+	def get_Resources(self): # String
 		return self.get_body_params().get('Resources')
 
-	def set_Resources(self,Resources):
+	def set_Resources(self, Resources):  # String
 		self.add_body_params('Resources', Resources)
-
-	def get_FunctionType(self):
+	def get_FunctionType(self): # String
 		return self.get_body_params().get('FunctionType')
 
-	def set_FunctionType(self,FunctionType):
+	def set_FunctionType(self, FunctionType):  # String
 		self.add_body_params('FunctionType', FunctionType)
-
-	def get_CmdDescription(self):
+	def get_CmdDescription(self): # String
 		return self.get_body_params().get('CmdDescription')
 
-	def set_CmdDescription(self,CmdDescription):
+	def set_CmdDescription(self, CmdDescription):  # String
 		self.add_body_params('CmdDescription', CmdDescription)
-
-	def get_UdfDescription(self):
+	def get_UdfDescription(self): # String
 		return self.get_body_params().get('UdfDescription')
 
-	def set_UdfDescription(self,UdfDescription):
+	def set_UdfDescription(self, UdfDescription):  # String
 		self.add_body_params('UdfDescription', UdfDescription)
-
-	def get_ParameterDescription(self):
+	def get_ParameterDescription(self): # String
 		return self.get_body_params().get('ParameterDescription')
 
-	def set_ParameterDescription(self,ParameterDescription):
+	def set_ParameterDescription(self, ParameterDescription):  # String
 		self.add_body_params('ParameterDescription', ParameterDescription)
-
-	def get_ProjectIdentifier(self):
+	def get_ProjectIdentifier(self): # String
 		return self.get_body_params().get('ProjectIdentifier')
 
-	def set_ProjectIdentifier(self,ProjectIdentifier):
+	def set_ProjectIdentifier(self, ProjectIdentifier):  # String
 		self.add_body_params('ProjectIdentifier', ProjectIdentifier)
-
-	def get_Example(self):
+	def get_Example(self): # String
 		return self.get_body_params().get('Example')
 
-	def set_Example(self,Example):
+	def set_Example(self, Example):  # String
 		self.add_body_params('Example', Example)
-
-	def get_FileName(self):
+	def get_FileName(self): # String
 		return self.get_body_params().get('FileName')
 
-	def set_FileName(self,FileName):
+	def set_FileName(self, FileName):  # String
 		self.add_body_params('FileName', FileName)
-
-	def get_ClassName(self):
+	def get_ClassName(self): # String
 		return self.get_body_params().get('ClassName')
 
-	def set_ClassName(self,ClassName):
+	def set_ClassName(self, ClassName):  # String
 		self.add_body_params('ClassName', ClassName)
-
-	def get_FileFolderPath(self):
+	def get_FileFolderPath(self): # String
 		return self.get_body_params().get('FileFolderPath')
 
-	def set_FileFolderPath(self,FileFolderPath):
+	def set_FileFolderPath(self, FileFolderPath):  # String
 		self.add_body_params('FileFolderPath', FileFolderPath)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # Long
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_body_params('ProjectId', ProjectId)
\ No newline at end of file
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_body_params('ProjectId', ProjectId)
