@@ -25,14 +25,14 @@ class DeleteDataSourceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'DeleteDataSource')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DataSourceId(self):
+	def get_DataSourceId(self): # Long
 		return self.get_query_params().get('DataSourceId')
 
-	def set_DataSourceId(self,DataSourceId):
-		self.add_query_param('DataSourceId',DataSourceId)
\ No newline at end of file
+	def set_DataSourceId(self, DataSourceId):  # Long
+		self.add_query_param('DataSourceId', DataSourceId)
