@@ -25,32 +25,29 @@ class GetFileVersionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetFileVersion')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FileVersion(self):
+	def get_FileVersion(self): # Integer
 		return self.get_body_params().get('FileVersion')
 
-	def set_FileVersion(self,FileVersion):
+	def set_FileVersion(self, FileVersion):  # Integer
 		self.add_body_params('FileVersion', FileVersion)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # Long
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # Long
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_ProjectIdentifier(self):
+	def get_ProjectIdentifier(self): # String
 		return self.get_body_params().get('ProjectIdentifier')
 
-	def set_ProjectIdentifier(self,ProjectIdentifier):
+	def set_ProjectIdentifier(self, ProjectIdentifier):  # String
 		self.add_body_params('ProjectIdentifier', ProjectIdentifier)
-
-	def get_FileId(self):
+	def get_FileId(self): # Long
 		return self.get_body_params().get('FileId')
 
-	def set_FileId(self,FileId):
-		self.add_body_params('FileId', FileId)
\ No newline at end of file
+	def set_FileId(self, FileId):  # Long
+		self.add_body_params('FileId', FileId)
