@@ -23,64 +23,56 @@ from aliyunsdkdataworks_public.endpoint import endpoint_data
 class GetMetaColumnLineageRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetMetaColumnLineage','dide')
+		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetMetaColumnLineage')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DataSourceType(self):
+	def get_DataSourceType(self): # String
 		return self.get_query_params().get('DataSourceType')
 
-	def set_DataSourceType(self,DataSourceType):
-		self.add_query_param('DataSourceType',DataSourceType)
-
-	def get_ClusterId(self):
+	def set_DataSourceType(self, DataSourceType):  # String
+		self.add_query_param('DataSourceType', DataSourceType)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_PageNum(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
-
-	def get_ColumnName(self):
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_ColumnName(self): # String
 		return self.get_query_params().get('ColumnName')
 
-	def set_ColumnName(self,ColumnName):
-		self.add_query_param('ColumnName',ColumnName)
-
-	def get_ColumnGuid(self):
+	def set_ColumnName(self, ColumnName):  # String
+		self.add_query_param('ColumnName', ColumnName)
+	def get_ColumnGuid(self): # String
 		return self.get_query_params().get('ColumnGuid')
 
-	def set_ColumnGuid(self,ColumnGuid):
-		self.add_query_param('ColumnGuid',ColumnGuid)
-
-	def get_DatabaseName(self):
+	def set_ColumnGuid(self, ColumnGuid):  # String
+		self.add_query_param('ColumnGuid', ColumnGuid)
+	def get_DatabaseName(self): # String
 		return self.get_query_params().get('DatabaseName')
 
-	def set_DatabaseName(self,DatabaseName):
-		self.add_query_param('DatabaseName',DatabaseName)
-
-	def get_PageSize(self):
+	def set_DatabaseName(self, DatabaseName):  # String
+		self.add_query_param('DatabaseName', DatabaseName)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_TableName(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_TableName(self): # String
 		return self.get_query_params().get('TableName')
 
-	def set_TableName(self,TableName):
-		self.add_query_param('TableName',TableName)
-
-	def get_Direction(self):
+	def set_TableName(self, TableName):  # String
+		self.add_query_param('TableName', TableName)
+	def get_Direction(self): # String
 		return self.get_query_params().get('Direction')
 
-	def set_Direction(self,Direction):
-		self.add_query_param('Direction',Direction)
\ No newline at end of file
+	def set_Direction(self, Direction):  # String
+		self.add_query_param('Direction', Direction)
