@@ -25,14 +25,19 @@ class GetProjectRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetProject')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_ProjectIdentifier(self): # String
+		return self.get_query_params().get('ProjectIdentifier')
 
-	def get_ProjectId(self):
+	def set_ProjectIdentifier(self, ProjectIdentifier):  # String
+		self.add_query_param('ProjectIdentifier', ProjectIdentifier)
+	def get_ProjectId(self): # Long
 		return self.get_query_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_query_param('ProjectId',ProjectId)
\ No newline at end of file
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_query_param('ProjectId', ProjectId)
