@@ -25,44 +25,39 @@ class ListDataServiceFoldersRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ListDataServiceFolders')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FolderNameKeyword(self):
+	def get_FolderNameKeyword(self): # String
 		return self.get_body_params().get('FolderNameKeyword')
 
-	def set_FolderNameKeyword(self,FolderNameKeyword):
+	def set_FolderNameKeyword(self, FolderNameKeyword):  # String
 		self.add_body_params('FolderNameKeyword', FolderNameKeyword)
-
-	def get_GroupId(self):
+	def get_GroupId(self): # String
 		return self.get_body_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
+	def set_GroupId(self, GroupId):  # String
 		self.add_body_params('GroupId', GroupId)
-
-	def get_PageSize(self):
-		return self.get_body_params().get('PageSize')
-
-	def set_PageSize(self,PageSize):
-		self.add_body_params('PageSize', PageSize)
-
-	def get_TenantId(self):
-		return self.get_body_params().get('TenantId')
-
-	def set_TenantId(self,TenantId):
-		self.add_body_params('TenantId', TenantId)
-
-	def get_ProjectId(self):
-		return self.get_body_params().get('ProjectId')
-
-	def set_ProjectId(self,ProjectId):
-		self.add_body_params('ProjectId', ProjectId)
-
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_body_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_body_params('PageNumber', PageNumber)
\ No newline at end of file
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_body_params('PageNumber', PageNumber)
+	def get_PageSize(self): # Integer
+		return self.get_body_params().get('PageSize')
+
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_body_params('PageSize', PageSize)
+	def get_TenantId(self): # Long
+		return self.get_body_params().get('TenantId')
+
+	def set_TenantId(self, TenantId):  # Long
+		self.add_body_params('TenantId', TenantId)
+	def get_ProjectId(self): # Long
+		return self.get_body_params().get('ProjectId')
+
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_body_params('ProjectId', ProjectId)
