@@ -25,50 +25,44 @@ class ListDataServicePublishedApisRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ListDataServicePublishedApis')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ApiNameKeyword(self):
+	def get_ApiNameKeyword(self): # String
 		return self.get_body_params().get('ApiNameKeyword')
 
-	def set_ApiNameKeyword(self,ApiNameKeyword):
+	def set_ApiNameKeyword(self, ApiNameKeyword):  # String
 		self.add_body_params('ApiNameKeyword', ApiNameKeyword)
-
-	def get_ApiPathKeyword(self):
+	def get_ApiPathKeyword(self): # String
 		return self.get_body_params().get('ApiPathKeyword')
 
-	def set_ApiPathKeyword(self,ApiPathKeyword):
+	def set_ApiPathKeyword(self, ApiPathKeyword):  # String
 		self.add_body_params('ApiPathKeyword', ApiPathKeyword)
-
-	def get_CreatorId(self):
+	def get_CreatorId(self): # String
 		return self.get_body_params().get('CreatorId')
 
-	def set_CreatorId(self,CreatorId):
+	def set_CreatorId(self, CreatorId):  # String
 		self.add_body_params('CreatorId', CreatorId)
-
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_body_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
+	def set_PageNumber(self, PageNumber):  # Integer
 		self.add_body_params('PageNumber', PageNumber)
-
-	def get_PageSize(self):
+	def get_PageSize(self): # Integer
 		return self.get_body_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
+	def set_PageSize(self, PageSize):  # Integer
 		self.add_body_params('PageSize', PageSize)
-
-	def get_TenantId(self):
+	def get_TenantId(self): # Long
 		return self.get_body_params().get('TenantId')
 
-	def set_TenantId(self,TenantId):
+	def set_TenantId(self, TenantId):  # Long
 		self.add_body_params('TenantId', TenantId)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # Long
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_body_params('ProjectId', ProjectId)
\ No newline at end of file
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_body_params('ProjectId', ProjectId)
