@@ -25,86 +25,79 @@ class UpdateDataServiceApiRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateDataServiceApi')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ScriptDetails(self):
+	def get_ScriptDetails(self): # String
 		return self.get_body_params().get('ScriptDetails')
 
-	def set_ScriptDetails(self,ScriptDetails):
+	def set_ScriptDetails(self, ScriptDetails):  # String
 		self.add_body_params('ScriptDetails', ScriptDetails)
-
-	def get_RequestMethod(self):
+	def get_RequestMethod(self): # Integer
 		return self.get_body_params().get('RequestMethod')
 
-	def set_RequestMethod(self,RequestMethod):
+	def set_RequestMethod(self, RequestMethod):  # Integer
 		self.add_body_params('RequestMethod', RequestMethod)
-
-	def get_ApiPath(self):
-		return self.get_body_params().get('ApiPath')
-
-	def set_ApiPath(self,ApiPath):
-		self.add_body_params('ApiPath', ApiPath)
-
-	def get_WizardDetails(self):
-		return self.get_body_params().get('WizardDetails')
-
-	def set_WizardDetails(self,WizardDetails):
-		self.add_body_params('WizardDetails', WizardDetails)
-
-	def get_VisibleRange(self):
-		return self.get_body_params().get('VisibleRange')
-
-	def set_VisibleRange(self,VisibleRange):
-		self.add_body_params('VisibleRange', VisibleRange)
-
-	def get_ApiDescription(self):
+	def get_ApiDescription(self): # String
 		return self.get_body_params().get('ApiDescription')
 
-	def set_ApiDescription(self,ApiDescription):
+	def set_ApiDescription(self, ApiDescription):  # String
 		self.add_body_params('ApiDescription', ApiDescription)
-
-	def get_Timeout(self):
+	def get_Timeout(self): # Integer
 		return self.get_body_params().get('Timeout')
 
-	def set_Timeout(self,Timeout):
+	def set_Timeout(self, Timeout):  # Integer
 		self.add_body_params('Timeout', Timeout)
+	def get_ResourceGroupId(self): # Long
+		return self.get_body_params().get('ResourceGroupId')
 
-	def get_RegistrationDetails(self):
-		return self.get_body_params().get('RegistrationDetails')
-
-	def set_RegistrationDetails(self,RegistrationDetails):
-		self.add_body_params('RegistrationDetails', RegistrationDetails)
-
-	def get_TenantId(self):
+	def set_ResourceGroupId(self, ResourceGroupId):  # Long
+		self.add_body_params('ResourceGroupId', ResourceGroupId)
+	def get_TenantId(self): # Long
 		return self.get_body_params().get('TenantId')
 
-	def set_TenantId(self,TenantId):
+	def set_TenantId(self, TenantId):  # Long
 		self.add_body_params('TenantId', TenantId)
-
-	def get_Protocols(self):
+	def get_Protocols(self): # String
 		return self.get_body_params().get('Protocols')
 
-	def set_Protocols(self,Protocols):
+	def set_Protocols(self, Protocols):  # String
 		self.add_body_params('Protocols', Protocols)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # Long
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # Long
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_ApiId(self):
-		return self.get_body_params().get('ApiId')
-
-	def set_ApiId(self,ApiId):
-		self.add_body_params('ApiId', ApiId)
-
-	def get_ResponseContentType(self):
+	def get_ResponseContentType(self): # Integer
 		return self.get_body_params().get('ResponseContentType')
 
-	def set_ResponseContentType(self,ResponseContentType):
-		self.add_body_params('ResponseContentType', ResponseContentType)
\ No newline at end of file
+	def set_ResponseContentType(self, ResponseContentType):  # Integer
+		self.add_body_params('ResponseContentType', ResponseContentType)
+	def get_ApiPath(self): # String
+		return self.get_body_params().get('ApiPath')
+
+	def set_ApiPath(self, ApiPath):  # String
+		self.add_body_params('ApiPath', ApiPath)
+	def get_WizardDetails(self): # String
+		return self.get_body_params().get('WizardDetails')
+
+	def set_WizardDetails(self, WizardDetails):  # String
+		self.add_body_params('WizardDetails', WizardDetails)
+	def get_VisibleRange(self): # Integer
+		return self.get_body_params().get('VisibleRange')
+
+	def set_VisibleRange(self, VisibleRange):  # Integer
+		self.add_body_params('VisibleRange', VisibleRange)
+	def get_RegistrationDetails(self): # String
+		return self.get_body_params().get('RegistrationDetails')
+
+	def set_RegistrationDetails(self, RegistrationDetails):  # String
+		self.add_body_params('RegistrationDetails', RegistrationDetails)
+	def get_ApiId(self): # Long
+		return self.get_body_params().get('ApiId')
+
+	def set_ApiId(self, ApiId):  # Long
+		self.add_body_params('ApiId', ApiId)
